Repeat

Struct Repeat 

pub struct Repeat<I> { /* private fields */ }
An index list consisting of an index repeated a finite number of times.

Implementations

Source

impl<I> Repeat<I>

pub fn value(value: I) -> Self

Construct an index list with 0 repetitions of the provided index value.

pub fn times(self, times: usize) -> Self

Construct a new index list where the current value is repeated the specified number of times.